#!/bin/bash

FILE_LOG="Config_Raid_Util.log"

print_data()
{
        echo "$*"
        echo "$*" >> "$FILE_LOG"
}

LogErrorExit()
{
        print_data "ERROR: $*"
        echo "Log File $FILE_LOG is located in `pwd`..."
        print_data "Exiting..."
        exit 1
}

getraidlog()
{
	date_var=`date +"%m-%d-%Y_%H-%M"`
        file_name=RaidLogs-"$date_var"
        mkdir "$file_name"

        megacli -AdpEventLog -getevents -f ./"$file_name"/RaidEvents.log -aALL
        megacli -AdpAllinfo -aALL > ./"$file_name"/RaidAllInfo.log
        megacli -CfgDsply -aALL > ./"$file_name"/CurrentRaidConfig.log

        print_data "Creating Compressed file $file_name.tgz in:"
        print_data "Path: `pwd`"
        cp "$FILE_LOG" ./"$file_name"
        tar -zcvf "./$file_name.tgz" "./$file_name"
        rm -r ./"$file_name"
	echo ""
        print_data "Please send $file_name.tgz to Support for analysis"
        print_data "Going Back to Main Menu"
}

check_which_drive()
{
itema=`megacli -PDInfo -PhysDrv[252:0] -a0 | grep "Firmware state: "`
itemb=`megacli -PDInfo -PhysDrv[252:1] -a0 | grep "Firmware state: "`
if [[ "$itema" == *Online* && "$itemb" == *Online* ]]
then
        print_data "Both Drives Are Online"
        print_data "Raid Configured"
elif [[ "$itema" == *Offline* && "$itemb" == *Offline* ]]
then
	print_data "Drive0: $itema"
	print_data "Drive1: $itemb"
        print_data "Trying to Set Online"
        megacli -PDOnline -PhysDrv[252:0,252:1] -a0		
else

        if [[ "$itema" == *bad* ]]
        then
                print_data "$itema"
                print_data "Drive 0 Needs To Be Changed"
                print_data "Top Drive"
        elif [[ "$itema" == *Rebuild* ]]
	then
		print_data "$itema"
		print_data "Drive 0 Rebuilding" 
	elif [[ "$itema" == *good* ]] 
	then
		print_data "$itema"
		print_data "Please go to Add Old Drive in Main Menu to add Drive 0"
	elif [ -z "$itema" ]
	then
		echo "Is Drive 0 On Slot? y|n"
                read cbvar
                if [[ "$cbvar" == "y" ]]
                then
                	print_data "Cannot Get Data From Drive 0 at this moment"
                        print_data "Please try again in 2 minutes"
                        print_data "Going Back to Main Menu"
                        return;
                 elif [[ "$cbvar" == "n" ]]
                 then
                        print_data "Please insert Drive on Slot 0 to Continue"
                        print_data "Contact Support if Help Needed"
                        print_data "Going Back to Main Menu"
                        return;
                 else
                        print_data "Not a Choice, Going Back to Main Menu"
                        return;
                 fi
	elif [[ "$itema" == *Offline* ]]
        then
                print_data "$itema"
                print_data "Trying to Set Online"
                megacli -PDOnline -PhysDrv[252:0] -a0
        elif [[ "$itema" != *Online* ]]
	then
                print_data "$itema"
                print_data "Drive State Not Supported for Drive 0"
	fi
        
	
	if [[ "$itemb" == *bad* ]]
        then
                print_data "$itemb"
                print_data "Drive 1 Needs To Be Changed"
                print_data "Bottom Drive"
        elif [[ "$itemb" == *Rebuild* ]]
        then
                print_data "$itemb"
                print_data "Drive 1 Rebuilding"
	elif [[ "$itemb" == *good* ]]
	then
                print_data "$itemb"
                print_data "Please go to Add Old Drive in Main Menu to add Drive 1"
        elif [ -z "$itemb" ]
	then
        	echo "Is Drive 1 On Slot? y|n"
                read cbvar
                if [[ "$cbvar" == "y" ]]
                then
                	print_data "Cannot Get Data From Drive 1 at this moment"
                        print_data "Please try again in 2 minutes"
                        print_data "Going Back to Main Menu"
                        return;
                 elif [[ "$cbvar" == "n" ]]
                 then
                        print_data "Please insert Drive on Slot 1 to Continue"
                        print_data "Contact Support if Help Needed"
                        print_data "Going Back to Main Menu"
                        return;
                 else
                        print_data "Not a Choice, Going Back to Main Menu"
                        return;
                 fi
	elif [[ "$itemb" == *Offline* ]]
        then
                print_data "$itemb"
                print_data "Trying to Set Online"
                megacli -PDOnline -PhysDrv[252:1] -a0
        elif [[ "$itemb" != *Online* ]] 
        then
	        print_data "$itema"
                print_data "Drive State Not Supported for Drive 1"
	fi
fi

print_data "Going Back To Main Menu"

}

reinsertdrive()
{
        megacli -PDMarkMissing -PhysDrv[252:"$driveid"] -a0 > /dev/null
        megacli -PDReplaceMissing -PhysDrv[252:"$driveid"] -Array0 -Row"$driveid" -a0 > /dev/null
        print_data "Wait 10 seconds for adding missing drive $driveid"
	sleep 10
	item=`megacli -PDInfo -PhysDrv[252:"$driveid"] -a0 | grep "Firmware
state: "`
        if [[ "$item" == *Online* ]]
        then
                megacli -PDOffline -PhysDrv[252,"$driveid"] -a0 > /dev/null
                megacli -PDRbld -Start -PhysDrv[252:"$driveid"] -a0 > /dev/null
        else
                megacli -PDRbld -Start -PhysDrv[252:"$driveid"] -a0 > /dev/null
        fi	
	print_data "Wait 2 minutes before checking for rebuild for Drive $driveid..."
        sleep 120
	return;
}


check_rebuild_process()
{
        print_data "" 
        date_var=`date`
        print_data "Start Time: $date_var"
        
	itema=`megacli -PDInfo -PhysDrv[252:0] -a0 | grep "Firmware state: "`
	itemb=`megacli -PDInfo -PhysDrv[252:1] -a0 | grep "Firmware state: "`
	if [[ -z "$itema" || -z "$itemb" ]]
	then
		if [ -z "$itema" ]
                then
                	echo "Is Drive 0 On Slot? y|n"
                        read cbvar
                        if [[ "$cbvar" == "y" ]]
                        then
                        	print_data "Cannot Get Data From Drive 0 at this moment"
                                print_data "Please try again in 2 minutes"
                                print_data "Going Back to Main Menu"
                                return;
                        elif [[ "$cbvar" == "n" ]]
                        then
                         	print_data "Please insert Drive on Slot 0 to Continue"
                                print_data "Contact Support if Help Needed"
                                print_data "Going Back to Main Menu"
                                return;
                        else
                                print_data "Not a Choice, Going Back to Main Menu"
                                return;
                        fi
                fi

                if [ -z "$itemb" ]
                then
                        echo "Is Drive 1 On Slot? y|n"
                        read cbvar
                        if [[ "$cbvar" == "y" ]]
                        then
                	        print_data "Cannot Get Data From Drive 1 at this moment"
                                print_data "Please try again in 2 minutes"
                                print_data "Going Back to Main Menu"
                                return;
                        elif [[ "$cbvar" == "n" ]]
                        then
                                print_data "Please insert Drive on Slot 1 to Continue"
                                print_data "Contact Support if Help Needed"
                                print_data "Going Back to Main Menu"
                                return;
                        else
                                print_data "Not a Choice, Going Back to Main Menu"
                                return;
                        fi
                fi
                        return;
	elif [[ "$itema" == *Online* && "$itemb" == *Online* ]]
	then
		print_data "Both Drives Are Online"
                date_var=`date`
                print_data "End Time: $date_var"
                item=`megacli -PDInfo -PhysDrv[252:0,252:1] -a0`
                print_data "$item"
                return;
	else

	        if [[ "$itema" == *Rebuild* ]]
        	then
               		drive_id=0
        	elif [[ "$itema" == *Offline* ]]
        	then
                	print_data "$itema"
                	print_data "Trying to Set Online"
                	megacli -PDOnline -PhysDrv[252:0] -a0
		elif [[ "$itema" != *Online* ]]
		then
                	print_data "$itema"
                	print_data "Please go to Add Old Drive in Main Menu to add Drive 0"
       			return;
		fi

	
		if [[ "$itemb" == *Rebuild* ]]
               	then
               	        drive_id=1
                elif [[ "$itemb" == *Offline* ]]
		then
                	print_data "$itemb"
               		print_data "Trying to Set Online"
                	megacli -PDOnline -PhysDrv[252:1] -a0
			return;
		elif [[ "$itemb" != *Online* ]]	
                then
		        print_data "$itemb"
                        print_data "Please go to Add Old Drive in Main Menu to add Drive 1"
			return;
		fi
         fi

         while true; do
                item=`megacli -PDInfo -PhysDrv[252:"$drive_id"] -a0 | grep "Firmware state: "`
                shopt -s nocasematch
                if [[ "$item" == *Rebuild* ]]
                then
                      date_var=`date`
                      print_data "$item, Date: $date_var"
		      print_data `megacli -PDRbld -ShowProg -PhysDrv[252:"$drive_id"] -a0`
                      sleep 30
                else
                      print_data "Final Result"
                      print_data "$item, Date: $date_var"
                      break;
                fi
                shopt -u nocasematch
         done
}


Add_Old_Drive()
{

drive0_id=0
drive1_id=1
driveid=3

	item=`megacli -PDInfo -PhysDrv[252:0] -a0 | grep "Firmware state: "`
        if [[ "$item" == *Online* ]]
        then
                item=`megacli -PDInfo -PhysDrv[252:1] -a0 | grep "Firmware state: "`
                if [[ "$item" == *Online* ]]
                then
                        print_data "Both Drives Are Online"
                        print_data "Nothing To Do..."
			return;
                elif [[ "$item" == *Rebuild* ]]
		then
			print_data "Drive 1 Rebuilding"
			return;
		elif [ -z "$item" ]
	        then
			echo "Is Drive 1 On Slot? y|n"
                        read cbvar
                        if [[ "$cbvar" == "y" ]]
                        then
                                print_data "Cannot Get Data From Drive 1 at this moment"
                                print_data "Please try again in 2 minutes"
                                print_data "Going Back to Main Menu"
                                return;
                        elif [[ "$cbvar" == "n" ]]
                        then
                                print_data "Please insert Drive on Slot 1 to Continue"
                                print_data "Contact Support if Help Needed"
                                print_data "Going Back to Main Menu"
                                return;
                        else
                                print_data "Not a Choice, Going Back to Main Menu"
                                return;
                        fi	
		elif [[ "$item" == *Offline* ]]
                then
                        print_data "$itemb"
                        print_data "Trying to Set Online"
                        megacli -PDOnline -PhysDrv[252:1] -a0
                        print_data "Going Back to Main Menu"
			return;
		else
			driveid=1			
			print_data "Trying to Clear Foreign configuration on Drive 1 if Any"
			megacli -CfgForeign -Clear -a0 #clears all foreign configuration on all drives
			print_data "Wait 30 seconds..."
			sleep 30
			print_data "Trying to change Drive 1 state to Unconfigured(good)"
			megacli -PDMakeGood -PhysDrv[252:1] -a0 #sets the drive state of drive 0 to unconfigured good
			print_data "Wait 30 seconds"
			sleep 30
		fi
	elif [[ "$item" == *Rebuild* ]]
	then 
		print_data "Drive 0 Rebuilding"
		return;
        elif [ -z "$item" ]
        then
			echo "Is Drive 0 On Slot? y|n"
                        read cbvar
                        if [[ "$cbvar" == "y" ]]
                        then
                        	print_data "Cannot Get Data From Drive 0 at this moment"
                                print_data "Please try again in 2 minutes"
				print_data "Going Back to Main Menu"
				return;
                        elif [[ "$cbvar" == "n" ]]
                        then
                                print_data "Please insert Drive on Slot 0 to Continue"
                                print_data "Contact Support if Help Needed"
                                print_data "Going Back to Main Menu"
                                return;
                        else
                                print_data "Not a Choice, Going Back to Main Menu"
                                return;
                        fi
	elif [[ "$item" == *Offline* ]]
        then
                        print_data "$itema"
                        print_data "Trying to Set Online"
                        megacli -PDOnline -PhysDrv[252:0] -a0
                        print_data "Going Back to Main Menu"
			return;
	else
		driveid=0
		print_data "Trying to Clear Foreign configuration on Drive 0 if Any"
                megacli -CfgForeign -Clear -a0 #clears all foreign configuration on all drives
                print_data "Wait 30 seconds..."
                sleep 30
                print_data "Trying to change Drive 0 state to Unconfigured(good)"
                megacli -PDMakeGood -PhysDrv[252:0] -a0 #sets the drive state of drive 0 to unconfigured good
                print_data "Wait 30 seconds"
                sleep 30

	fi

#Call reinsert drive to tell the costumer what to do
reinsertdrive
ccvar=5
cbvar=5
while true; do
                item=`megacli -PDInfo -PhysDrv[252:"$driveid"] -a0 | grep "Firmware state: "`
                shopt -s nocasematch
                if [[ "$item" == *Rebuild* ]]
                then
                      date_var=`date`
                      print_data "$item, Date: $date_var"
                      sleep 30 
		elif [[ "$item" == *Online* ]]
                then
		      print_data "Final Result"
                      print_data "$item, Date: $date_var"
                      break;
		elif [[ "$item" == *good* ]]
		then
		      print_data "Drive "$driveid" still has state, trying $ccvar more times"
		      print_data "$item"
		      reinsertdrive
		      ccvar=$(( $ccvar - 1 ))
		elif [[ "$item" == *Offline* ]]
                then
                        print_data "$item"
                        print_data "Trying to Set Online"
                        megacli -PDOnline -PhysDrv[252:"$driveid"] -a0
                        break;
		elif [[ -z "$item" && "$cbvar" -ne 0 ]] 
        	then
                        print_data "Cannot Get Data From Drive at this moment"
                	print_data "Please try again in 2 minutes if Drive on Slot"
			print_data "Trying $cbvar more times"
			print_data " Wait 1 More Minute..."
			cbvar=$(( $cbvar - 1 ))
			sleep 60	
		elif [ "$cbvar" == 0 ]
		then
			print_data "ERROR: Could Not Get Data From Drive"
			print_data "ERROR: Drive Could Not Be Found"
			print_data "ERROR: Make sure drive is in Slot, if it is then contact Support"
			print_data "ERROR: Going back to main Menu"
			break;
		else
		      print_data "ERROR: Drive $driveid stil has Firmware State"
		      print_data "ERROR: $item"
		      print_data "ERROR: Drive Cannot Be Re-Used"
		      print_data "ERROR: Please Call Support"
		      break;
		fi
	
        	if [ "$ccvar" -eq 0 ]
        	then
                	print_data "ERROR: Could not Re-Use Drive"
                	print_data "ERROR: Please Call Support"
			break; 
	        fi
                shopt -u nocasematch
done

}

Prepare_Drives()
{
print_data "Clearing Current Configuration if Any"
megacli -CfgDsply -a0 #Clears Current Configuration
print_data "Wait 30 seconds..."
sleep 30

if [[ "$itema" != *good* ]]
then
	print_data "Trying to change drive 0 state to unconfigure(good)"
	megacli -PDMakeGood -PhysDrv[252:0] -a0 #sets the drive state of drive 0 to unconfigured good
fi
if [[ "$itemb" != *good* ]]
then
	print_data "Trying to change drive 1 state to unconfigure(good)"
        megacli -PDMakeGood -PhysDrv[252:1] -a0 #sets the drive state of drive 0 to unconfigured good
fi
print_data "Wait 30 seconds..."
sleep 30

print_data "Clearing Current Foreign State on Drives if Any"
megacli -CfgForeign -Clear -a0 #clears all foreign configuration on all drives
print_data "Wait 30 seconds..."
sleep 30

megacli -AdpEventLog -Clear -a0

megacli -CfgClr -a0 

print_data "Configuratin Raid 0 and adding both drives"
megacli -CfgLDAdd -R1 [252:0,252:1] -WT -NORA -a0 #tells raid the raid type and drives to map
print_data "wait 60 seconds..."
sleep 60

}

Rebuild_Raid()
{

enclosure_id=252

drive0_id=0
drive1_id=1

	itema=`megacli -PDInfo -PhysDrv[252:0] -a0 | grep "Firmware state: "`
        itemb=`megacli -PDInfo -PhysDrv[252:1] -a0 | grep "Firmware state: "`
        if [[ "$itema" == *Online* && "$itemb" == *Online* ]]
        then
                 print_data "Both Drives Are Online"
                 print_data "Are You Sure You Want To Rebuild?"
                 print_data "You will lose all configuration"
                 print_data "y|n"
                 read choicevar
                 if [[ "$choicevar" == "y" ]]
                 then
                 #Do nothing
                 choicevar="y"
                 elif [[ "$choicevar" == "n" ]]
                 then
		 	print_data "NOT Rebuilding"
        	        return;
                 else
                        print_data "Not a Choice, Going Back to Main Menu"
                        return;
                 fi
        elif [[ "$itema" == *Offline* && "$itemb" == *Offline* ]]
	then
		print_data "Drive0: $itema"
        	print_data "Drive1: $itemb"
        	print_data "Trying to Set Online"
        	megacli -PDOnline -PhysDrv[252:0,252:1] -a0
		print_data "Going Back to Main Menu"
		return;
	else
                if [[ -z "$itema" || -z "$itemb" ]]
                then
                        if [ -z "$itema" ]
                        then
                                echo "Is Drive 0 On Slot? y|n"
                        	read cbvar
                        	if [[ "$cbvar" == "y" ]]
                        	then
                                	print_data "Cannot Get Data From Drive 0 at this moment"
                                	print_data "Please try again in 2 minutes"
                                	print_data "Going Back to Main Menu"
                                	return;
                        	elif [[ "$cbvar" == "n" ]]
                        	then
                                	print_data "Please insert Drive on Slot 0 to Continue"
                                	print_data "Contact Support if Help Needed"
                                	print_data "Going Back to Main Menu"
                                	return;
                        	else
                                	print_data "Not a Choice, Going Back to Main Menu"
                                	return;
                        	fi
			fi

                        if [ -z "$itemb" ]
                        then
				echo "Is Drive 1 On Slot? y|n"
                        	read cbvar
                        	if [[ "$cbvar" == "y" ]]
                        	then
                                	print_data "Cannot Get Data From Drive 1 at this moment"
                                	print_data "Please try again in 2 minutes"
                                	print_data "Going Back to Main Menu"
                                	return;
                        	elif [[ "$cbvar" == "n" ]]
                        	then
                                	print_data "Please insert Drive on Slot 1 to Continue"
                                	print_data "Contact Support if Help Needed"
                                	print_data "Going Back to Main Menu"
                                	return;
                        	else
                                	print_data "Not a Choice, Going Back to Main Menu"
                                	return;
				fi
                        fi
			return;	
                elif [[ "$itema" != *Online* && "$itemb" == *Online* ]]
                then
                        if [[ "$itema" == *Offline* ]]
                        then
                                print_data "$itema"
                                print_data "Trying to Set Online"
                                megacli -PDOnline -PhysDrv[252:0] -a0
                                print_data "Going Back to Main Menu"
                                return;
                        fi
                        print_data "Drive 0 is NOT online BUT Drive 1 is Online"
                        print_data "Try to Reinsert Drive To Raid by going to Main Menu and Choosing Add Old Drive"
                        print_data "Raid Reconfiguration is NOT supported when any Drive is Online"
                        print_data "NOT Rebuilding"
                        print_data "Going Back to Main Menu"
                        return;
                elif [[ "$itema" == *Online* && "$itemb" != *Online* ]]
                then
                        if [[ "$itemb" == *Offline* ]]
                        then
                                print_data "$itemb"
                                print_data "Trying to Set Online"
                                megacli -PDOnline -PhysDrv[252:1] -a0
                                print_data "Going Back to Main Menu"
                                return;
                        fi
                        print_data "Drive 1 is NOT online BUT Drive 0 is Online"
                        print_data "Try to Reinsert Drive To Raid by going to Main Menu and Choosing Add Old Drive"
                        print_data "Raid Reconfiguration is NOT supported when any Drive is Online"
                        print_data "NOT Rebuilding"
                        print_data "Going Back to Main Menu"
                        return;
		elif [[ "$itema" == *Offline* || "$itemb" == *Offline* ]]
		then
			print_data "One of your Drives is Offline, Raid Reconfiguration not supported if any Drive Offline"
			if [[ "$itema" == *Offline* ]]
			then
				print_data "Drive0: $itema"
                                print_data "Trying to Set Online"
                                megacli -PDOnline -PhysDrv[252:0] -a0
			fi
			if [[ "$itemb" == *Offline* ]]
			then
				print_data "Drive 1: $itemb"
                                print_data "Trying to Set Online"
                                megacli -PDOnline -PhysDrv[252:1] -a0
			fi
			print_data "Going Back to Main Menu"
			return;	
		elif [[ "$itema" == *Rebuild* || "$itemb" == *Rebuild* ]]
                then
                        if [[ "$itema" == *Rebuild* ]]
                        then
                                print_data "Drive 0 is Rebuilding, Raid Reconfiguration Not Supported when any Drive is Rebuilding"
                        fi
                        if [[ "$itemb" == *Offline* ]]
                        then	
				print_data "Drive 1  is Rebuilding, Raid Reconfiguration Not Supported when any Drive is Rebuilding"
                        fi
			print_data "Going Back to Main Menu"
                        return;
		else
			print_data "Both Drives have states:"
			print_data "Drive 0: $itema"
			print_data "Drive 1: $itemb"
			print_data "Starting Rebuilding Process"
		fi
        fi

#Calling Prepare Drives function 
Prepare_Drives

vccount=0
while true; do
	print_data "Checking if both Drives are online"
	itema=`megacli -PDInfo -PhysDrv[252:0] -a0 | grep "Firmware state: "`
	itemb=`megacli -PDInfo -PhysDrv[252:1] -a0 | grep "Firmware state: "`
	if [[ "$itema" == *Online* && "$itemb" == *Online* ]]
	then
		print_data "Both Drives Are Online"
                print_data "Continue with Setup..."
                break;

	elif [[ -z "$itema" || -z "$itemb" ]]
        then
                if [ -z "$itema" ]
                then
			echo "Is Drive 0 On Slot? y|n"
                        read cbvar
                        if [[ "$cbvar" == "y" ]]
                        then
                        	print_data "Cannot Get Data From Drive 0 at this moment"
                        	print_data "Please try again in 2 minutes"
				print_data "Going Back to Main Menu"
				return;
                        elif [[ "$cbvar" == "n" ]]
                        then
                        	print_data "Please insert Drive on Slot 0 to Continue"
                        	print_data "Contact Support if Help Needed"
                        	print_data "Going Back to Main Menu"
                        	return;
                        else
                        	print_data "Not a Choice, Going Back to Main Menu"
                        	return;
                        fi
 
                fi
                if [ -z "$itemb" ]
                then
	        	echo "Is Drive 1 On Slot? y|n"
                        read cbvar
                        if [[ "$cbvar" == "y" ]]
                        then
                        	print_data "Cannot Get Data From Drive 1 at this moment"
                                print_data "Please try again in 2 minutes"
                                print_data "Going Back to Main Menu"
                                return;
                        elif [[ "$cbvar" == "n" ]]
                        then
                                print_data "Please insert Drive on Slot 1 to Continue"
                                print_data "Contact Support if Help Needed"
                                print_data "Going Back to Main Menu"
                                return;
                        else
                                print_data "Not a Choice, Going Back to Main Menu"
                                return;
                        fi        
		fi
                return;
	else
		if [[ "$itema" != *Online* ]]
                then
			print_data "Drive 0 is NOT online, current state is:"
			print_data "$itema"
		fi
		if [[ "$itemb" == *Online* ]]
                then
			print_data "Drive 1 is NOT online, current state is:"
                        print_data "$itemb"
		fi
	fi

	vccount=$(( $vccount + 1 ))
	if [ "$vccount" -gt 5 ]
	then
		print_data "ERROR: Could not set both drives online"
		print_data "ERROR: Make sure both drives are good and well placed on suckets"
		return;	
	else
		#Calling Prepare Drives function
		print_data "Cound Not Set Drives Online"
		print_data "Try number $vccount out of 5 total possible tries"
		Prepare_Drives			
	fi
done

print_data "Trying to Initialize Raid..."
megacli -LDInit -Start Full -L0 -a0 #Initializes the Raid Configuration, will take some time
print_data "Wait 30 seconds before asking for status"
sleep 30

print_data "Checking Status on Raid Initialization if it did not fail to start"
while true; do

	initstatus=`megacli -LDInit -ShowProg -L0 -a0 | grep "Initialization on VD"` #Show progress of Raid Configuration Initialization
	if [[ "$initstatus" == *"is not in progress"* ]]
	then
		print_data "Initialization Done"
		break;
	else
		print_data "$initstatus, `date`"
		sleep 30
	fi
done	

}

getraidfirmware()
{
	allinfo=`megacli -AdpAllinfo -aALL`;
	raid_fw=`echo "$allinfo" | grep  "FW Package Build" | tr -d 'FW Package Build: '`
	print_data "Current Raid Firmware Version: $raid_fw"
	print_data "Going Back To Main Menu"
	return;
}

type -P provhwinfo &>/dev/null && { print_data "Getting Appliance Model"; appliance=`provhwinfo  | grep "Model Number: " | tr -d 'Model Number: '`;} || { print_data "provhwinfo not found" ; print_data "Please Specify Appliance Model" ; read appliance;}

if [[ "$appliance" != "GX5008" && "$appliance" != "GX5108" && "$appliance" != "GX5208" ]]
then
        print_data "Error: Script does NOT support Appliance Model: $appliance"
        print_data "Error: Script meant for appliance model GX5008, GX5108, and GX5208".
else
        type -P /usr/sbin/megacli &>/dev/null && { print_data "Getting Raid info"; allinfo=`megacli -AdpAllinfo -aALL`;} || { LogErrorExit "megacli command NOT found"; }

        raid_name=`echo "$allinfo" | grep "Product Name" | sed -e "s/Product\ Name\ \ \ \ \:\ //"`

        if [ -z "$raid_name" ]
        then
                print_data "Please verify raid is MR10i"
                print_data "$allinfo"
                LogErrorExit "Raid Does NOT display raid info"
        fi

        shopt -s nocasematch
        if [[ "$raid_name" != *mr10i* || "$raid_name" == *mr10ie* ]]
        then
                LogErrorExit Raid Controller "$raid_name" Not Supported for Update
                shopt -u nocasematch
        else
                shopt -u nocasematch

		 print_data "Please specify configuration process"

		PS3="Pleae Enter Main Menu Choice :"
		OPTIONS=("Rebuild Raid" "Check Any Drive Needs Changing" "Add Old Drive" "Check Rebuild Process" "Get Raid Logs" "Display Raid Firmware Version" "Quit")
		select opt in "${OPTIONS[@]}"
		do
       			case $opt in
        		"Rebuild Raid")
                		print_data "Are you running this from Provdiag Prompt?";
                		print_data "yes|no";
               			read ccchoice;
                		if [[ "$ccchoice" == "yes" ]]
                		then
                       			print_data "Rebuilding Raid Configuration";
                        		Rebuild_Raid;
                		elif [[ "$ccchoice" == "no" ]]
				then
                        		print_data "Please Ask Support for procedure to get to Provdiag Prompt";
                        		print_data "Cannot Rebuild Raid Configuration While Useing A Drive in Raid"
                		else
					print_data "Not a Choice"
					print_data "Going Back To Main Menu"
				fi;;
        		"Check Any Drive Needs Changing")
                		print_data "Checking Drive To Change";
                		check_which_drive;;
        		"Add Old Drive")
                		print_data "Adding Old Drive To Raid Configuration";
                		Add_Old_Drive;;
        		"Check Rebuild Process")
                		print_data "Check Rebuild Process";
                		check_rebuild_process;;
			"Get Raid Logs")
				print_data "Getting Raid Logs";
				getraidlog;;
			"Display Raid Firmware Version")
				print_data "Getting Current Raid Firmware Version";
				getraidfirmware;;
        		"Quit")
                		break;;
        		*)
                		print_data "Choice NOT Supported";;
        		esac
			
		done

        fi
fi

echo "Log File $FILE_LOG is located in `pwd`"
