#!/bin/bash

STATUS_ERR=0
STATUS_WARN=0

#Variables to set depending on patch
patch_fw="11.0.1-0042"
install_file="ibm_fw_sraidmr_10i-10is-11.0.1-0042_linux_32-64.bin"
hist_file="ibm_fw_sraidmr_10i-10is-11.0.1-0042_linux_32-64.chg"
####################VariableS#######################

Log() { echo $* ; }

LogError()
{
    Log ERROR: $*
    STATUS_ERR=1
}

LogErrorExit()
{
    Log ERROR: $*
    STATUS_ERR=1
    ErrorExit
}

LogWarning()
{
    Log WARNING: $*
    STATUS_WARN=1
}

cleanup()
{
	if [ -f CmdTool.log ]
        then
                rm -rf CmdTool.log
        fi
        if [ -f CtDbg.log ]
        then
                rm -rf CtDbg.log
        fi
        if [ -f MegaSAS.log ]
        then
                rm -rf MegaSAS.log
        fi
	return;
}

ErrorExit()
{
	echo ""
	if [ $STATUS_ERR -ne 0 ] ; then
       		Log "result_code = failed"
        	Log "Raid Firmware Installation Failed"
		exit 1
	fi
}

setupcheckforraid()
{
	if [ -f /usr/bin/chk4raid ]
	then
		rm -r /usr/bin/chk4raid
	fi
	if [ -f /etc/init.d/checkforraid ]
	then
		insserv -r /etc/init.d/checkforraid
		if [ -f /sbin/checkforraid ]
	        then
        	        rm -r /sbin/checkforraid
        	fi
		rm -r /etc/init.d/checkforraid
	fi
	if [ -f /sbin/checkforraid ]
	then
		rm -r /sbin/checkforraid
	fi
	cp chk4raid /usr/bin/
	cp checkforraid /etc/init.d/
	chmod  744 /usr/bin/chk4raid
	chmod 744 /etc/init.d/checkforraid
	ln -s /etc/init.d/checkforraid /sbin/checkforraid
	insserv /etc/init.d/checkforraid
}

type -P provhwinfo &>/dev/null && { echo "Getting Appliance Model"; appliance=`provhwinfo  | grep "Model Number: " | tr -d 'Model Number: '`;} || { LogWarning provhwinfo not found ; echo "Please Specify Appliance Model" ; read appliance;}

echo "Verifying all files necessary exist and are not corrupted..."
echo "" 
echo "Checking for: $install_file"

if [ -e "$install_file" ] 
then
	install_chksum=`md5sum "$install_file" | awk '{print $1 }'`
	if [[ "$install_chksum" == "d9800e0305496d68d0a2e350329e0e37" ]]
	then 
		echo "OK"
	else
		LogError File "$install_file" is Corrupted 
        	LogErrorExit Please remove patch from appliance, and re-copy it over and try again
	fi

else
	LogError File "$install_file" Does not exist
	LogErrorExit Make sure file is inside same folder as install.sh script before continuing
fi


echo "Checking for: $hist_file"

if [ -e "$hist_file" ]
then
	hist_chksum=`md5sum "$hist_file" | awk '{print $1 }'`
	if [[ "$hist_chksum" == "63d7553b416cb6206e8fafbaf472d88c" ]]
        then
                echo "OK"
        else
                LogError Error: File "$hist_file" is Corrupted
                LogErrorExit Please remove patch from appliance, re-copy it over and try again
	fi

else
        LogError File "$hist_file" Does not exist
        LogErrorExit Make sure file is inside same folder as install.sh script before continuing
fi

if [[ "$appliance" != "GX5008" && "$appliance" != "GX5108" && "$appliance" != "GX5208" ]]
then
	LogError Patch does NOT support Appliance Model: "$appliance" 
	LogErrorExit Please verify correct version of patch is being installed.
else

	type -P /usr/sbin/megacli &>/dev/null && { echo "Getting Raid info"; allinfo=`megacli -AdpAllinfo -aALL`;} || { LogErrorExit "megacli command NOT found"; }

	#allinfo=`megacli -AdpAllinfo -aALL`
	raid_fw=`echo "$allinfo" | grep  "FW Package Build" | tr -d 'FW Package Build: '`
	raid_name=`echo "$allinfo" | grep "Product Name" | sed -e "s/Product\ Name\ \ \ \ \:\ //"`
	mfg_date=`echo "$allinfo" | grep "Mfg. Date" | tr -d 'Mfg. Date       : '` 
	
	while true; do
		echo  "Are you running this from Provdiag Prompt?"
                echo "yes|no|Don't Know"
                read ccchoose
                if [[ "$ccchoose" == "yes" ]]
                then
                	ipsprompt="FALSE"
			break;                
		elif [[ "$ccchoose" == "no" ]]
                then
                	ipsprompt="TRUE" 
			break;               
		elif [[ "$ccchoose" == "Don't Know" ]]
		then
			Log "Contact Support"
			Log "Now Exiting..."
			exit 0;
		else
                        echo "Not a Choice"
                        echo "Please enter one of the three choices yes|no|Don't Know"
                fi
	done


	if [[ -z "$raid_fw" || -z "$raid_name" ]]
	then	
		LogErrorExit Could NOT get Raid Info from Raid Controller
		#LogWarning Could NOT get Raid Info from Raid Controller
		#LogWarning Getting Raid Info from User Manually
		#if [ -z "$raid_fw" ]
		#then
		#	echo "Please Specify Raid's current firmware installed in the format XX.X.X-XXXX ( i.e 11.0.1-0024 )"
		#	read raid_fw
		#fi
		#
		#if [ -z "$raid_name" ]
       		#then
               	#	echo "Please Specify Raid Controller Name. i.e MR10i"
                #	read raid_name
        	#fi
		
	fi
	
	echo ""
	echo "Raid Name: $raid_name"
	
	if [ -n "$mfg_date" ]
	then
		echo "Mfg. Date: $mfg_date"
	fi
	
	shopt -s nocasematch
	if [[ "$raid_name" != *mr10i* || "$raid_name" == *mr10ie* ]]
	then
		LogErrorExit Raid Controller "$raid_name" Not Supported for Update 
		shopt -u nocasematch
	else	
		shopt -u nocasematch
		echo "Current Firmware Installed $raid_fw" 
		echo ""
		echo "Trying to Install Raid Firmware Version $patch_fw"  

		
		if [ "$raid_fw" = "$patch_fw" ]
		then
			LogWarning Patch "$patch_fw" Already Installed
			if [[ "$ipsprompt" == "TRUE" ]] 
			then
				setupcheckforraid	
				service checkforraid start 	
			fi
		elif [ "$raid_fw" \< "$patch_fw" ]
		then
			
			while true; do
				echo "Appliance will reboot automatically after Installation"
				echo "Do you want to Continue?  yes|no"
				read ccval
				if [[ "$ccval" == "yes" ]]
				then
					break;
				elif [[ "$ccval" == "no" ]]
				then
					echo "You chose NOT to continue, Exiting..."
					exit 0
				else
					echo "Not A Choice"
				fi
			done

			echo "Please Do NOT turn off or unplug appliance until installation done"
        		echo "Upgrading Raid Controller Firmware from $raid_fw to $patch_fw..."
        		
			# Make patch executable
			chmod +x $install_file
		 	# Install Patch	
			./$install_file -s
			if [ $? -eq 0 ]
			then
				echo "OK"
			else
				echo "" 
				LogErrorExit Patch Installation Failed. Please Contact Support.
			fi 
			if [[ "$ipsprompt" == "TRUE" ]]
                        then
				setupcheckforraid
			fi
			echo "Appliance will Reboot in 2 minutes"
			sleep 120
			reboot &  
		else
			LogError Downgrading Raid Firmware Not Supported
			LogErrorExit Current Raid Firmware "$raid_fw"
		fi
	fi
fi

echo ""
cleanup
if [ $STATUS_ERR -ne 0 ] ; then
	Log "result_code = failed"
        Log "Raid Firmware Installation Failed"
 	exit 1
elif [ $STATUS_WARN -ne 0 ] ; then
        Log "result_code = warning"
        Log "Raid Firmware Installation completed with warnings"
	exit 0
else
        Log "result_code = success"
        Log "Raid Firmware Installation Completed Successfully"
        exit 0
fi


##########################END#################################
